@@ -4,7 +4,7 @@
 # LAST MODIFIED ON: 2021/3/1 3:46 PM
 # AIM:
 from abc import ABC
-from typing import List
+from typing import List, Union
 import re
 
 from .abc import Criteria
@@ -67,28 +67,42 @@ class IsEndSymbolEN(Criteria):
         self.is_right_s_quota = IsRightSingleQuotaEn()
         self.not_in_white_list = NotInWhitelistDotEn(white_list=white_list)
 
-    def look_forward(self, state: StrSequence) -> str:
+    def look_forward(self, state: EnSequence, by_idx: bool = False) -> Union[str, int]:
         for i in range(state.v_pointer + 1, state.length):
             if not self.empty.match(state[i]):
-                return state[i]
+                if by_idx:
+                    return i
+                else:
+                    return state[i]
         else:
-            return state.current_value
+            if by_idx:
+                return state.v_pointer
+            else:
+                return state.current_value
 
-    def look_backward(self, state: StrSequence) -> str:
+    def look_backward(self, state: EnSequence, by_idx: bool = False) -> Union[str, int]:
         for i in range(0, state.v_pointer)[::-1]:
             if not self.empty.match(state[i]):
-                return state[i]
+                if by_idx:
+                    return i
+                else:
+                    return state[i]
         else:
-            return state.current_value
+            if by_idx:
+                return state.v_pointer
+            else:
+                return state.current_value
 
-    def accept(self, state: StrSequence) -> bool:
-        if self.symbols['end_symbols'].match(state.current_value):
+    def accept(self, state: EnSequence) -> bool:
+        if self.is_right_quota(state):
             print()
+
         if self.symbols['end_symbols'].match(state.current_value) and not self.symbols['end_symbols'].match(
                 self.look_forward(state)):
             return True
         if (self.is_right_quota(state) or self.is_right_s_quota(state)) and self.symbols['end_symbols'].match(
-                self.look_backward(state)) and self.look_forward(state)[0].isupper():
+                self.look_backward(state)) and self.look_forward(state)[
+            0].isupper() and self.not_in_white_list.is_valid(state, self.look_backward(state, by_idx=True)):
             return True
         return False
 
@@ -498,8 +512,7 @@ class NotInWhitelistDotEn(SpecialCondition):
 
     def __init__(self, white_list: str):
         super(NotInWhitelistDotEn, self).__init__('NotInWhitelistDotEn', SYMBOLS_EN)
-        pattern = re.compile('\s')
-        self.white_list = [pattern.sub('', v.strip()) for v in white_list.splitlines()]
+        self.white_list = [v.strip() for v in white_list.splitlines()]
 
     def accept(self, state: EnSequence) -> bool:
         return self.is_valid(state, state.v_pointer)
@@ -538,20 +551,19 @@ class NotInWhitelistDotEn(SpecialCondition):
                 word_token = state.tokenize(word)
                 dots_pos = self.find_dot(word_token)
                 word_len = len(word_token)
-                atcual_word = ''.join(state[index - dots_pos:index])
-                if dots_pos == word_len and word == atcual_word:
+                atcual_word = ''.join(state[index - dots_pos:index + 1])
+                if dots_pos == word_len - 1 and word == atcual_word:
                     return False
-                if dots_pos != word_len:
+                if dots_pos != word_len - 1:
                     # case Mac. book 走搜索
                     while dots_pos > 0:
-                        i = 0
                         whole_word = atcual_word + ''.join(
-                            state[index:index + i + word_len - dots_pos])
+                            state[index + 1:index + word_len - dots_pos])
                         if word == whole_word:
                             # state.v_pointer = state.v_pointer + i + word_len - dots_pos
                             return False
                         dots_pos = self.find_dot(word_token, dots_pos + 1)
-                        atcual_word = ''.join(state[index - dots_pos:index])
+                        atcual_word = ''.join(state[index - dots_pos:index+1])
             return True
 
     def find_dot(self, str_list: List[str], start=0):
