@@ -221,7 +221,8 @@ class LongHandlerEN(Operation):
                 return i, True
 
             if (self.is_right_quota(state) or self.is_s_right(
-                    state) or (state.current_value in '）)' and self.is_next_with_space(state))) and sub_len > self.min_sentence_length:
+                    state) or (state.current_value in '）)' and self.is_next_with_space(state))) and self.is_dialogue_gt(
+                state) and sub_len > self.min_sentence_length:
                 return i, True
 
             # if self.is_next_with_space(state) and self.is_end_symbol(state) and self.not_in_white_list(
