@@ -252,9 +252,9 @@ class test_spliter(unittest.TestCase):
                   'the underpinning of our safety, prosperity,',
                   ' and liberty, but “from different causes and from different quarters much '
                   'pains will be taken… to weaken in your minds the conviction of this truth;” ',
-                  'that we should preserve it with “jealous anxiety;”',
-                  ' that we should reject “the first dawning of every attempt to alienate any '
-                  'portion of our country from the rest or to enfeeble the sacred ties” ',
+                  'that we should preserve it with “jealous anxiety;” that we should reject '
+                  '“the first dawning of every attempt to alienate any portion of our country '
+                  'from the rest or to enfeeble the sacred ties” ',
                   'that make us one.']
         m_input = EnSequence(paragraph)
         __long_machine_en.run(m_input)
@@ -282,10 +282,11 @@ class test_spliter(unittest.TestCase):
         m_input = EnSequence(paragraph)
         __long_machine_en.run(m_input)
         acutal = m_input.sentence_list()
-        expect = ["The show's writers gave these tropes a 2021 refresh by leaning into the \"woke\"",
-                  ' culture of millennials and Gen Z, calling out intolerance, accepting and '
-                  'normalising LGBTQ+ issues, and highlighting struggles faced by minorities '
-                  'living in the US – African-Americans in particular.']
+        expect = ["The show's writers gave these tropes a 2021 refresh by leaning into the "
+                  '"woke" culture of millennials and Gen Z,',
+                  ' calling out intolerance, accepting and normalising LGBTQ+ issues, and '
+                  'highlighting struggles faced by minorities living in the US – '
+                  'African-Americans in particular.']
         self.assertEqual(expect, acutal)
 
     # @unittest.skip('pass')
@@ -393,9 +394,11 @@ class test_spliter(unittest.TestCase):
         expect = ['Lee Bo-jin is the second daughter of the chairman of Samsung, the "genuine" '
                   "heir of Korea's largest chaebol.",
                   " Ms. Lee is currently running the family's Shilla hotel chain.",
-                  ' With everything from money to power, Lee Bo-jin has always been dubbed the "No. 1 Korean woman"',
-                  ' and ranked 87th in the top 100 most powerful women in the world voted by Forbes magazine.',
-                  ' However, inside that flashy life is a tragic life of the "Samsung princess".',
+                  ' With everything from money to power, Lee Bo-jin has always been dubbed the '
+                  '"No. 1 Korean woman" and ranked 87th in the top 100 most powerful women in '
+                  'the world voted by Forbes magazine.',
+                  ' However, inside that flashy life is a tragic life of the "Samsung '
+                  'princess".',
                   ' *\n    *Princess means the richest woman in the country.']
 
         self.assertEqual(expect, acutal)
@@ -421,9 +424,9 @@ class test_spliter(unittest.TestCase):
         m_input = EnSequence(paragraph)
         __long_machine_en.run(m_input)
         acutal = m_input.sentence_list()
-        expect = ['The night was rapidly approaching; and already, at the cry of “Moccoletti!”',
-                  ' repeated by the shrill voices of a thousand vendors, two or three stars '
-                  'began to burn among the crowd.',
+        expect = ['The night was rapidly approaching; and already, at the cry of “Moccoletti!” '
+                  'repeated by the shrill voices of a thousand vendors,',
+                  ' two or three stars began to burn among the crowd.',
                   ' It was a signal. At the end of ten minutes fifty thousand lights glittered,',
                   ' descending from the Palazzo di Venezia to the Piazza del Popolo, and '
                   'mounting from the Piazza del Popolo to the Palazzo di Venezia.',
