@@ -71,8 +71,9 @@ class test_spliter(unittest.TestCase):
         acutal = m_input.sentence_list()
         print(acutal)
         expect = ['embattled we are-- but a call to bear the burden of a long twilight '
-                  'struggle, year in and year out,"rejoicing in hope, patient in tribulation"--',
-                  'a struggle against the common enemies of man: tyranny, poverty, disease and war itslef.']
+                  'struggle, year in and year out,',
+                  '"rejoicing in hope, patient in tribulation"--a struggle against the common '
+                  'enemies of man: tyranny, poverty, disease and war itslef.']
         self.assertEqual(expect, acutal)
 
     # @unittest.skip('pass')
@@ -86,8 +87,9 @@ class test_spliter(unittest.TestCase):
         print(acutal)
         expect = ['\'"I thought it too, when I went off watch"--',
                   'we was standing six hours on and six off--',
-                  '"but the boys told me, " I says, " thata the raft didn\'t seem to hardly move, for the last hour," ',
-                  'says I, "thought she\'s a slipping along all right, now,"']
+                  '"but the boys told me, " I says,',
+                  ' " thata the raft didn\'t seem to hardly move, for the last hour," says I, '
+                  '"thought she\'s a slipping along all right, now,"']
         self.assertEqual(expect, acutal)
 
     # @unittest.skip('pass')
@@ -163,6 +165,7 @@ class test_spliter(unittest.TestCase):
             "'It's her surname,' said my mother, faintly."]
         self.assertEqual(expect, acutal)
 
+    # @unittest.skip('pass')
     def test_bug_2021_4_29(self):
         paragraph = "(Do you mean to say, child, that any human being has gone into a Christian church, and got herself named Peggotty?) It's her surname, said my mother, faintly."
         __long_machine_en = StateMachine(long_cuter_en(min_len=6, max_len=21))
@@ -171,10 +174,11 @@ class test_spliter(unittest.TestCase):
         acutal = m_input.sentence_list()
         print(acutal)
         expect = ['(Do you mean to say, child, that any human being has gone into a Christian '
-                  'church, and got herself named Peggotty?) ',
-                  "It's her surname, said my mother, faintly."]
+                  'church, and got herself named Peggotty?)',
+                  " It's her surname, said my mother, faintly."]
         self.assertEqual(expect, acutal)
 
+    # @unittest.skip('pass')
     def test_bug_2021_4_29_1(self):
         paragraph = " ' Do you mean to say, child, that any human being has gone' into a Christian church, and got herself named Peggotty?"
         __long_machine_en = StateMachine(long_cuter_en(min_len=6, max_len=15))
@@ -192,7 +196,7 @@ class test_spliter(unittest.TestCase):
         __long_machine_en.run(m_input)
         acutal = m_input.sentence_list()
         print(acutal)
-        expect = [" ' Do you mean to say, child,",
-                  " that any human being has gones' into a Christian church, and got herself "
-                  'named Peggotty?']
+        expect = [" ' Do you mean to say, child, that any human being has gones' into a "
+                  'Christian church,',
+                  ' and got herself named Peggotty?']
         self.assertEqual(expect, acutal)
