@@ -98,8 +98,7 @@ class test_spliter(unittest.TestCase):
 
     # @unittest.skip('pass')
     def test_bug_2021_5_24_2(self):
-        paragraph = "I wept like a child. \"Dear mountains! my own beautiful lake! " \
-                    "How do you welcome your wanderer? Your summits are clear; the sky and lake are blue and placid. Is this to prognosticate peace, or to mock at my unhappiness?\""
+        paragraph = "I wept like a child. \"Dear mountains! my own beautiful lake! How do you welcome your wanderer? Your summits are clear; the sky and lake are blue and placid. Is this to prognosticate peace, or to mock at my unhappiness?\""
         __long_machine_en = StateMachine(long_cuter_en(min_len=6, max_len=30))
         m_input = EnSequence(paragraph)
         __long_machine_en.run(m_input)
@@ -352,6 +351,9 @@ I wept like a child. "Dear mountains! my own beautiful lake! how do you welcome
     # 这个是一个分复杂的例子
     def test_bug_2021_5_25_14(self):
         paragraph = '''"Yeh always wait fer the hippogriff ter make the firs' move," Hagrid cointinued. "It's polite, see? Yeh walk toward him, and yeh bow, an' yeh wait. If he bows back, yeh're allowed ter toych him. If he desn' bow, then get away from him sharpish,' cause those talons hurt.'''
+
+        paragraph = "\"Yeh always wait fer the hippogriff ter make the firs' move,\" Hagrid cointinued. \"It's polite, see? Yeh walk toward him, and yeh bow, an' yeh wait. If he bows back, yeh're allowed ter toych him. If he desn' bow, then get away from him sharpish,' cause those talons hurt."
+
         __long_machine_en = StateMachine(long_cuter_en(min_len=6, max_len=30))
         m_input = EnSequence(paragraph)
         __long_machine_en.run(m_input)
@@ -369,3 +371,6 @@ I wept like a child. "Dear mountains! my own beautiful lake! how do you welcome
         __long_machine_en.run(m_input)
         acutal = m_input.sentence_list()
         print(acutal)
+        expect = ['In the new economy, computer science isn\'t an optional skill – it\'s a basic skill, right along with the three "Dr."',
+                  " Steven Nine out of ten parents want it taught at their children's schools"]
+        self.assertEqual(expect, acutal)
\ No newline at end of file
